endpoint property
String
get
endpoint
The endpoint of the request, should be set by the subclass
Implementation
String get endpoint;
The endpoint of the request, should be set by the subclass
String get endpoint;